// 
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
// Autogenerated from Pigeon (v9.2.4), do not edit directly.
// See also: https://pub.dev/packages/pigeon

#import <Foundation/Foundation.h>

@protocol FlutterBinaryMessenger;
@protocol FlutterMessageCodec;
@class FlutterError;
@class FlutterStandardTypedData;

NS_ASSUME_NONNULL_BEGIN

@class LegacyCredentialStoreData;

@interface LegacyCredentialStoreData : NSObject
+ (instancetype)makeWithIdentityId:(nullable NSString *)identityId
    accessKeyId:(nullable NSString *)accessKeyId
    secretAccessKey:(nullable NSString *)secretAccessKey
    sessionToken:(nullable NSString *)sessionToken
    expirationMsSinceEpoch:(nullable NSNumber *)expirationMsSinceEpoch
    accessToken:(nullable NSString *)accessToken
    refreshToken:(nullable NSString *)refreshToken
    idToken:(nullable NSString *)idToken;
@property(nonatomic, copy, nullable) NSString * identityId;
@property(nonatomic, copy, nullable) NSString * accessKeyId;
@property(nonatomic, copy, nullable) NSString * secretAccessKey;
@property(nonatomic, copy, nullable) NSString * sessionToken;
@property(nonatomic, strong, nullable) NSNumber * expirationMsSinceEpoch;
@property(nonatomic, copy, nullable) NSString * accessToken;
@property(nonatomic, copy, nullable) NSString * refreshToken;
@property(nonatomic, copy, nullable) NSString * idToken;
@end

/// The codec used by NativeAuthPlugin.
NSObject<FlutterMessageCodec> *NativeAuthPluginGetCodec(void);

@interface NativeAuthPlugin : NSObject
- (instancetype)initWithBinaryMessenger:(id<FlutterBinaryMessenger>)binaryMessenger;
/// Exchanges the route parameters used to launch the app, i.e. if the app
/// was closed and a redirect happened to the custom URI scheme (iOS) or an
/// intent was launched with the redirect parameters (Android).
- (void)exchangeParams:(NSDictionary<NSString *, NSString *> *)params completion:(void (^)(FlutterError *_Nullable))completion;
@end

/// The codec used by NativeAuthBridge.
NSObject<FlutterMessageCodec> *NativeAuthBridgeGetCodec(void);

@protocol NativeAuthBridge
/// Sign in by presenting [url] and waiting for a response to a URL with
/// [callbackUrlScheme].
///
/// If [preferPrivateSession] is `true`, do not persist session cookies.
- (void)signInWithUrlUrl:(NSString *)url callbackUrlScheme:(NSString *)callbackUrlScheme preferPrivateSession:(NSNumber *)preferPrivateSession browserPackageName:(nullable NSString *)browserPackageName completion:(void (^)(NSDictionary<NSString *, NSString *> *_Nullable, FlutterError *_Nullable))completion;
/// Sign out by presenting [url] and waiting for a response to a URL with
/// [callbackUrlScheme].
- (void)signOutWithUrlUrl:(NSString *)url callbackUrlScheme:(NSString *)callbackUrlScheme preferPrivateSession:(NSNumber *)preferPrivateSession browserPackageName:(nullable NSString *)browserPackageName completion:(void (^)(FlutterError *_Nullable))completion;
/// Retrieves the validation data for the current iOS/Android device.
///
/// @return `nil` only when `error != nil`.
- (nullable NSDictionary<NSString *, NSString *> *)getValidationDataWithError:(FlutterError *_Nullable *_Nonnull)error;
/// @return `nil` only when `error != nil`.
- (nullable NSString *)getBundleIdWithError:(FlutterError *_Nullable *_Nonnull)error;
/// Fetch legacy credentials stored by native SDKs.
- (void)getLegacyCredentialsIdentityPoolId:(nullable NSString *)identityPoolId appClientId:(nullable NSString *)appClientId completion:(void (^)(LegacyCredentialStoreData *_Nullable, FlutterError *_Nullable))completion;
/// Clears the legacy credential store data.
- (void)clearLegacyCredentialsWithCompletion:(void (^)(FlutterError *_Nullable))completion;
@end

extern void NativeAuthBridgeSetup(id<FlutterBinaryMessenger> binaryMessenger, NSObject<NativeAuthBridge> *_Nullable api);

NS_ASSUME_NONNULL_END
